@@ -1,11 +1,15 @@
 package RDF::DOAP::Person;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = 0.003;
+our $VERSION   = 0.004;
 
 use Moose;
 extends qw(RDF::DOAP::Resource);
 
+use overload
+	q[""]    => sub { shift->to_string },
+	fallback => 1;
+
 use RDF::DOAP::Types -types;
 use RDF::DOAP::Utils -traits;
 
@@ -27,6 +31,8 @@ has mbox => (
 	coerce     => 1,
 	uri        => $foaf->mbox,
 	multi      => 1,
+	lazy       => 1,
+	builder    => '_build_mbox',
 );
 
 has cpanid => (
@@ -40,11 +46,20 @@ sub _build_cpanid
 {
 	my $self = shift;
 	return unless $self->has_rdf_about;
-	$self->rdf_about =~ m{^http://purl\.org/NET/cpan-uri/person/(\w+)$}
+	return unless $self->rdf_about->is_resource;
+	$self->rdf_about->uri =~ m{^http://purl\.org/NET/cpan-uri/person/(\w+)$}
 		and return $1;
 	return;
 }
 
+sub _build_mbox
+{
+	my $self = shift;
+	return [sprintf('mailto:%s@cpan.org', $self->cpanid)]
+		if defined $self->cpanid;
+	return [];
+}
+
 sub to_string
 {
 	my $self = shift;
@@ -63,7 +78,7 @@ sub to_string
 		push @parts, $self->name;
 		if ($self->cpanid)
 		{
-			push @parts, sprintf('(cpan:%s)', uc $self->cpanid);
+			push @parts, sprintf('(%s)', uc $self->cpanid);
 		}
 	}
 	else
@@ -72,7 +87,7 @@ sub to_string
 		push @parts, $nick if $nick;
 	}
 	
-	for my $mbox (@{$self->mbox || []})
+	for my $mbox (@{$self->mbox})
 	{
 		if ($mbox and $mbox->uri =~ /^mailto:(.+)$/)
 		{
@@ -81,7 +96,7 @@ sub to_string
 		}
 	}
 	
-	for my $mbox (@{$self->mbox || []})
+	for my $mbox (@{$self->mbox})
 	{
 		push @parts, $mbox if !@parts;
 	}
