@@ -1,7 +1,7 @@
 package RDF::DOAP::Resource;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = 0.003;
+our $VERSION   = 0.004;
 
 use Moose;
 
@@ -113,20 +113,20 @@ sub rdf_get
 	croak "This object cannot rdf_get; stopped"
 		unless $self->has_rdf_model && $self->has_rdf_about;
 	
-	my @values = $self->model->objects_for_predicate_list(@_);
+	my @values = $self->rdf_model->objects_for_predicate_list(@_);
 	wantarray ? @values : $values[0];
 }
 
 sub rdf_get_literal
 {
-	my $self = shift;	
+	my $self = shift;
 	my @values = grep $_->is_literal, $self->rdf_get(@_);
 	wantarray ? @values : $values[0];
 }
 
 sub rdf_get_uri
 {
-	my $self = shift;	
+	my $self = shift;
 	my @values = grep $_->is_resource, $self->rdf_get(@_);
 	wantarray ? @values : $values[0];
 }
